@@ -13,19 +13,17 @@
 namespace Oxygen
 {
 
-    //______________________________________________
-    bool WidgetStateData::updateState( bool value )
-    {
-        if( _state == value ) return false;
-        else {
-
-            _state = value;
-            animation().data()->setDirection( _state ? Animation::Forward : Animation::Backward );
-            if( !animation().data()->isRunning() ) animation().data()->start();
-            return true;
-
-        }
-
+//______________________________________________
+bool WidgetStateData::updateState(bool value)
+{
+    if (_state == value)
+        return false;
+    else {
+        _state = value;
+        animation().data()->setDirection(_state ? Animation::Forward : Animation::Backward);
+        if (!animation().data()->isRunning())
+            animation().data()->start();
+        return true;
     }
-
+}
 }
